==> phoenix_widgets-1.11.1.tar.gz: example/lib/phoenix_list_group_page.dart <==
import 'package:flutter/material.dart';
import 'package:phoenix_widgets/phoenix_widgets.dart';

class PhoenixListGroupPage extends StatefulWidget {
  const PhoenixListGroupPage({Key? key}) : super(key: key);

  @override
  _PhoenixListGroupPageState createState() => _PhoenixListGroupPageState();
}

class _PhoenixListGroupPageState extends State<PhoenixListGroupPage> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        title: const Text('Phoenix List Group Sample'),
      ),
      body: PhoenixListGroup(
        groupList: _sampleGrouping,
      ),
    );
  }
}

Map<String, List<DataHelper>> _sampleGrouping = {
  'Data 1': [
    DataHelper(
        title: 'Title Data 2.1',
        desc: 'Description Data 2.1',
        isSelected: true,
        isVisible: false),
    DataHelper(
        title: 'Title Data 2.2',
        desc: 'Description Data 2.2',
        isSelected: true,
        isVisible: true),
    DataHelper(
        title: 'Title Data 2.3',
        desc: 'Description Data 2.3',
        isSelected: true,
        isVisible: true),
  ],
  'Data 2': [
    DataHelper(
        title: 'Title Data 2.1',
        desc: 'Description Data 2.1',
        isSelected: true,
        isVisible: true),
    DataHelper(
        title: 'Title Data 2.2',
        desc: 'Description Data 2.2',
        isSelected: true,
        isVisible: false),
    DataHelper(
        title: 'Title Data 2.3',
        desc: 'Description Data 2.3',
        isSelected: true,
        isVisible: true),
  ]
};

==> phoenix_widgets-1.17.3.tar.gz: example/lib/phoenix_list_group_page.dart <==
import 'package:flutter/material.dart';
import 'package:phoenix_widgets/phoenix_widgets.dart';

class PhoenixListGroupPage extends StatefulWidget {
  const PhoenixListGroupPage({Key? key}) : super(key: key);

  @override
  State<PhoenixListGroupPage> createState() => _PhoenixListGroupPageState();
}

class _PhoenixListGroupPageState extends State<PhoenixListGroupPage> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        title: const Text('Phoenix List Group Sample'),
      ),
      body: PhoenixListGroup(
        groupList: _sampleGrouping,
        hideLastDivider: true,
      ),
    );
  }
}

Map<String, List<DataHelper>> _sampleGrouping = {
  'Data 1': [
    DataHelper(
        title: 'Title Data 2.1',
        desc: 'Description Data 2.1',
        isSelected: true,
        isVisible: false),
    DataHelper(
        title: 'Title Data 2.2',
        desc: 'Description Data 2.2',
        isSelected: true,
        isVisible: true),
    DataHelper(
        title: 'Title Data 2.3',
        desc: 'Description Data 2.3',
        isSelected: true,
        isVisible: true),
  ],
  'Data 2': [
    DataHelper(
        title: 'Title Data 2.1',
        desc: 'Description Data 2.1',
        isSelected: true,
        isVisible: true),
    DataHelper(
        title: 'Title Data 2.2',
        desc: 'Description Data 2.2',
        isSelected: true,
        isVisible: false),
    DataHelper(
        title: 'Title Data 2.3',
        desc: 'Description Data 2.3',
        isSelected: true,
        isVisible: true),
  ]
};
